@@ -3,31 +3,32 @@ from voip_shifts.bot import bot
 from rq.job import get_current_job
 from sqlalchemy import and_, select
 from tzlocal import get_localzone
+import re
 
 import subprocess
 
 from voip_shifts.models import *
-from voip_shifts.config import config, mode, log, session, rq
+from voip_shifts.config import Config, log, session, rq
 
 
 
 class Shifts():
     def __init__(self, employee_id:str, client_id:str, service_id:str, 
                 start_date:datetime, end_date:datetime, minutes_time_delta:int, 
-                active:bool, skip:bool) -> None:
-        if mode == "prod":
-            self.sip_server = config.SIP_SERVER
-            self.password = config.SIP_PASSWORD
-            self.number = config.SIP_NUMBER
-            self.username = config.SIP_USERNAME
-        self.client_id = client_id
+                active:bool, skip:bool, source_phone:str, destination_phone:str) -> None:
+        self.sip_server = Config.SIP_SERVER
+        self.password = Config.SIP_PASSWORD
+        self.username = Config.SIP_USERNAME
         self.employee_id = employee_id
+        self.client_id = client_id
         self.service_id = service_id
         self.minutes_time_delta = minutes_time_delta
         self.start_date = start_date
         self.end_date = end_date
         self.active = active
         self.skip = skip
+        self.source_phone = source_phone
+        self.destination_phone = destination_phone
         self.on_shift_call = f"1+++++++{self.client_id}+++++"
         self.off_shift_call = f"2+++++++{self.client_id}+++++{self.service_id}+++++++1+++0+++++"
 
@@ -50,7 +51,7 @@ class Shifts():
             bot.send_messages(msg)
             return None
 
-        if mode == "prod":
+        if Config.MODE == "prod":
             subprocess.run(
                 [
                     "./call-prog",
@@ -61,9 +62,9 @@ class Shifts():
                     "-p",
                     self.password,
                     "-n",
-                    self.number,
+                    self.source_phone,
                     "-t",
-                    "18558442600@" + self.sip_server,
+                    f"1{self.destination_phone}@" + self.sip_server,
                     "-d",
                     f"+4++++++{self.employee_id}++++++++2++++++{type_of_call}",
                     "-T",
@@ -72,8 +73,14 @@ class Shifts():
                     "9001",
                 ]
             )
-        msg = f"""Employee {self.employee_id} is {'On shift Call' if type_of_call is self.on_shift_call else 'Off shift call'}
-            with {self.client_id}, service:{self.service_id} at {datetime.utcnow()} UTC0"""
+        else:
+            log.info(f"""./call-prog, -r {self.sip_server} -u {self.username} -p {self.password} -n \
+                    {self.source_phone} -t {self.destination_phone}@{self.sip_server} -d \
+                    +4++++++{self.employee_id}++++++++2++++++{type_of_call} -T \
+                    {self.get_printable_time(datetime_)}_{self.client_id} -P 9001""")
+
+        msg = f"""Employee {self.employee_id} is {'On shift Call' if type_of_call is self.on_shift_call else 'Off shift call'} \
+                  with {self.client_id}, service:{self.service_id} at {datetime.utcnow()} UTC0"""
         bot.send_messages(msg)
         log.info(f"Shift call executed {get_current_job().id}")
         timetable = session.scalar(
@@ -83,8 +90,8 @@ class Shifts():
         )
         daily_report = session.scalar(
             select(DailyReportModel).filter(and_(
-                DailyReportModel.company_id==timetable.company_id,
-                DailyReportModel.date==datetime_.date()
+                DailyReportModel.company==timetable.company,
+                DailyReportModel.date==timetable.date
             ))
         )
 
@@ -92,7 +99,7 @@ class Shifts():
             daily_report = DailyReportModel(
                 call_count = 0,
                 date = datetime_.date(),
-                company_id = timetable.company,
+                company_id = timetable.company_id,
             )
             session.add(daily_report)
             session.flush()
@@ -111,8 +118,9 @@ class Shifts():
             session.commit()
         except Exception as e:
             log.error(f"Commit don't exist. Exception is {e}")
+            bot.send_messages(f"EXCEPTION: {e}")
             session.rollback()
         else:
-            log.info(f"Off shift call job id is record with {job.id}")
+            log.info(f"Data recorded")
         finally:
             session.close()
